use lecture9.dta, clear

* Tell Stata this is TSCS data
tsset stfips year 

* What predicts murder rates?
******************************

*
* data prep work
*

* per capita police spending, state + local
gen policePC = policeex1/totalpop
* per capita welfare spending, state + local
gen welfarePC = welfare1/totalpop
* per capita education spending, state + local
gen edspendPC = edspend1/totalpop
* log population
gen logpop = log(totalpop)
* log per capita income
gen logpcinc = log(PInccapC)


*
* list some variables we will consider
*
describe murder adperI policePC welfarePC edspendPC PInccapC logpop deathst
sum year


*
* basic model
*

regress murder adperI policePC edspendPC logpcinc logpop deathst, robust

*
* get rid of some missing observations (gaps important for TSCS data)
*

* missing years?
sum year if e(sample)
drop if year<=1977 | year>2002

* what's left?
gen nonmiss = 0
replace nonmiss = 1 if e(sample)
list stname year if(nonmiss==0)
* drop 2001-2002 and DC
drop if stname=="District of Columbia"
drop if year>2000



* 
* correct for spatial/temporal correlation
*

xtpcse murder adperI policePC edspendPC logpcinc logpop

* include AR(1) correlation
xtpcse murder adperI policePC edspendPC logpcinc logpop, correlation(ar1)
xtpcse murder adperI policePC edspendPC logpcinc logpop, correlation(psar1)


*
* correct for unit heterogeneity 
*

xtreg murder adperI policePC edspendPC logpcinc logpop, fe
xtreg murder adperI policePC edspendPC logpcinc logpop, re

* Hausman test


xtreg murder adperI policePC edspendPC logpcinc logpop, fe
est store consistent
xtreg murder adperI policePC edspendPC logpcinc logpop, re
est store efficient

hausman consistent efficient